@@ -915,7 +915,7 @@
 				if ( checkPage.tokenWidget ) {
 					tokenWidgets.push( checkPage.tokenWidget );
 				}
-				deferreds.push( checkPage.apiCheckValid() );
+				deferreds.push( ...checkPage.apiCheckValid() );
 				checkPage.getQueryParams( params, displayParams, ajaxOptions );
 				if ( checkPage.paramInfo.mustbeposted !== undefined ) {
 					method = 'post';
@@ -989,6 +989,19 @@
 					return;
 				}
 
+				if ( params.format === undefined ) {
+					// While not required by the API, the sandbox UI makes the 'format' parameter required.
+					// If we reach this point without any value for it, that's a bug, so stop here
+					// (it would result in incorrect formatting on the results panel).
+					throw new Error( "'format' parameter is required" );
+				}
+				if ( params.action === undefined ) {
+					// While not required by the API, the sandbox UI makes the 'action' parameter required.
+					// If we reach this point without any value for it, that's a bug, so stop here
+					// (it would result in dumping the entire HTML help output on the results panel).
+					throw new Error( "'action' parameter is required" );
+				}
+
 				const query = $.param( displayParams );
 
 				const formatItems = Util.formatRequest( displayParams, params, method, ajaxOptions );
@@ -1143,11 +1156,6 @@
 							}
 							$result.append( Util.parseHTML( data.html ) );
 							loadTime = data.time;
-						} else if ( ( match = data.match( /<pre[ >][\s\S]*<\/pre>/ ) ) ) {
-							$result.append( Util.parseHTML( match[ 0 ] ) );
-							if ( ( match = data.match( /"wgBackendResponseTime":\s*(\d+)/ ) ) ) {
-								loadTime = parseInt( match[ 1 ], 10 );
-							}
 						} else {
 							$( '<pre>' )
 								.addClass( 'api-pretty-content' )
